Moana
=====

| |pypi| |versions| |license|

..
    ===========  =================================================
    **latest**   |travis-latest| |codecov-latest| |docs-latest|
    **develop**  |travis-develop| |codecov-develop| |docs-develop|
    ===========  =================================================

Moana is a Python package.


.. |pypi| image:: https://img.shields.io/pypi/v/moana.svg
    :target: https://pypi.python.org/pypi/moana
    :alt: PyPI version

.. |versions| image:: https://img.shields.io/pypi/pyversions/moana.svg
    :target: https://pypi.python.org/pypi/moana
    :alt: Python versions supported

.. |license| image:: https://img.shields.io/pypi/l/moana.svg
    :target: https://pypi.python.org/pypi/moana
    :alt: License

.. |travis-latest| image:: https://travis-ci.org/flo-compbio/moana.svg?branch=master
    :alt: Build Status (master branch)
    :target: https://travis-ci.org/flo-compbio/moana

.. |travis-develop| image:: https://travis-ci.org/flo-compbio/moana.svg?branch=develop
    :alt: Build Status (develop branch)
    :target: https://travis-ci.org/flo-compbio/moana

.. |codecov-latest| image:: https://codecov.io/github/flo-compbio/moana/coverage.svg?branch=master
    :alt: Coverage (master branch)
    :target: https://codecov.io/github/flo-compbio/moana?branch=master

.. |codecov-develop| image:: https://codecov.io/github/flo-compbio/moana/coverage.svg?branch=develop
    :alt: Coverage (develop branch)
    :target: https://codecov.io/github/flo-compbio/moana?branch=develop

.. |docs-latest| image:: https://readthedocs.io/projects/moana/badge/?version=latest
    :alt: Documentation Status (master branch)
    :target: https://moana.readthedocs.io/en/latest

.. |docs-develop| image:: https://readthedocs.io/projects/moana/badge/?version=develop
    :alt: Documentation Status (develop branch)
    :target: https://moana.readthedocs.io/en/develop

.. _gtdocs: https://moana.readthedocs.org/en/latest/
